@@ -1,6 +1,6 @@
 /* test4.c */
 /*
- Copyright 2001-2004 John Coffman.
+ Copyright 2001-2005 John Coffman.
  All rights reserved.
 
  Licensed under the terms contained in the file 'COPYING' in the LILO
@@ -8,9 +8,9 @@
 
 */
 #include <bios.h>
-#include "../bdata.h"
+#include "../src/bdata.h"
 
-#define DISK_VERSION "2.2.4"
+#define DISK_VERSION "2.4"
 
 #if __MSDOS__==0
 #define putch bios_putc
@@ -28,6 +28,8 @@
 #define SPACER "\f\n"
 #define SEQ 0x3C4
 
+#define FS_REG 0x80
+
 #ifndef EDD_SUBSET
 #define EDD_SUBSET 4
 #define EDD_LOCK 2
@@ -36,6 +38,7 @@
 #ifndef SECTOR_SIZE
 #define SECTOR_SIZE 512
 #endif
+#define nelem(a) (sizeof(a)/sizeof((a)[0]))
 
 typedef unsigned char  byte;
 typedef unsigned short word;
@@ -48,6 +51,7 @@ union REGS reg, oreg;
 struct SREGS sreg;
 int last_good_disk;
 int video_1 = 0xF00;
+int fs_mod = 0;
 int num_hd = BD_MAX_HARD;
 int errno;
 dword hma;	/* highest memory address */
@@ -69,6 +73,41 @@ struct gdt_entry {
 
 struct gdt_entry gdt[6];
 
+static
+int get_fs(void)
+{
+#asm
+ mov ax,fs
+#endasm
+}
+
+static
+int set_fs(int val)
+{
+    int i = val;
+#asm
+ mov ax,4[bp]
+ mov fs,ax
+#endasm
+    return i;
+}
+
+static
+int check_fs(void)
+{
+    int ret = 0;
+
+#if DEBUG>=2    
+    printf("#");
+#endif    
+    if (get_fs() != FS_REG) {
+        fs_mod = ret = 1;
+        printf("\nThe FS register has been modified.\n");
+        set_fs(FS_REG);
+    }
+    return ret;
+}
+
 static
 int hicopy (unsigned long to, unsigned long from, int wcount)
 {
@@ -126,10 +165,32 @@ bios_putc0(int c)
 {
     union REGS reg;
     if (c=='\f') {
+#if 0
     	reg.h.ah = 0x0F;
     	int86(0x10, &reg, &reg);
     	reg.h.ah = 0;
     	int86(0x10, &reg, &reg);
+#else
+	static word upper = 0;
+	if (!upper) {
+	    __set_es(0x40);	/* address BIOS data area */
+	    upper = __peek_es(0x84);
+	    if (upper < 24 || upper > 50) upper = 24;
+	    upper <<= 8;
+	    reg.h.ah = 0x0F;	/* get video mode */
+	    int86(0x10, &reg, &reg);
+	    upper |= (reg.h.ah-1);
+	}
+	reg.x.ax = 0x0600;	/* blank screen area */
+	reg.h.bh = 7;
+	reg.x.cx = 0x0000;
+	reg.x.dx = upper;
+	int86(0x10, &reg, &reg);
+	reg.h.ah = 2;		/* set cursor position */
+	reg.h.bh = 0;
+	reg.x.dx = 0x0000;
+	int86(0x10, &reg, &reg);
+#endif
     } else {
     	reg.h.al = c;
     	reg.h.ah = 14;
@@ -226,7 +287,7 @@ void banner(char *version)
 {
 	printf(	"\n\n\n"
 ">>>> Disk Detection and Parameter Display <<<<\n\n\n"
-"Version %s, Copyright (C) 1999-2004  John Coffman <johninsd@san.rr.com>\n"
+"Version %s, Copyright (C) 1999-2005  John Coffman <johninsd@san.rr.com>\n"
 "Portions Copyright (C) 1996-2001 Robert de Bath, used with permission\n"
 "Re-use and redistribution rights set forth in the file \"COPYING\".\n\n",
 	 version);
@@ -377,7 +438,8 @@ static
 void pause(void)
 {
 	char ch;
-/* Must be standalone */    
+/* Must be standalone */
+        check_fs();
 	printf("\n\n\nHit <Enter> to continue, <^C> to quit ...");
 	do {
 	    ch = getch();
@@ -810,6 +872,7 @@ void do_edd(int dev)
 	} eddparam;
 
 	pause();
+	m = !!(oreg.x.cx&EDD_SUBSET)  &&  oreg.h.ah>=0x21;
 	printf(SPACER
 		"Int 13h  Function 48h\t\t[EDD]\n"
 		"EDD Get Drive Parameters (device %02xh)\n\n"
@@ -846,8 +909,51 @@ void do_edd(int dev)
 	    decimal(eddparam.sectors_lo);
 	else printf("0x%x%08x", eddparam.sectors_hi, eddparam.sectors_lo);
 	printf(" sectors)\n");
-    }
 #undef fl
+	m=1;
+	if (m) {
+	    static char *cfunc[] = {
+		"Enable Prefetch",
+		"Disable Prefetch",
+		"Set Maximum PIO Mode",
+		"Set PIO Mode 0",
+		"Set Default PIO Mode",
+		"Enable DMA Maximum Mode",
+		"Disable DMA"
+	    };
+	    m = 0;		/* start with subfn 0 */
+	    pause();
+	    printf(SPACER
+		"Int 13h  Function 4Eh\t\t[EDD]\n"
+		"Subfunction 0?h\n"
+		"EDD Set Hardware Configuration (device %02xh)\n\n"
+		"Call With:\n    ", dev);
+	    reg.x.ax = 0x4E00;
+	    reg.h.dl = dev;
+	    print_regs(&reg);
+	    int86(0x13, &reg, &reg);
+	    printf("\nReturns:\n    ");
+	    print_regs(&reg);
+	    print_carry(reg.x.cflag);
+	    printf("\n");
+	    
+	    for (m=0; m<nelem(cfunc); m++) {
+		reg.x.ax = 0x4E00 + m;
+		reg.h.dl = dev;
+		int86(0x13, &reg, &reg);
+		printf("Subfn(%d):  %s  <--  ", m, cfunc[m]);
+		if (reg.x.cflag || reg.h.ah) {
+		    printf("is not supported.\n");
+		}
+		else {
+		    printf("%s other drives on controller.\n",
+			reg.h.al ? "affects" : "does not affect");
+		}
+	    } /* for */
+	    
+	} /* if (m) */
+	
+    } /* if (m) */
 }
 
 static
@@ -932,6 +1038,7 @@ static char *dt[] = {	"5.25\", 40 track, 360K",
 			printf("Error:  Hard disk BIOS should not touch ES:DI\n");
 		}
 		s = (oreg.h.cl & 0x3F);		/* sectors 1..63 */
+		if (s == 0) s = 64;
 		h = (int)oreg.h.dh + 1;		/* heads 0..254 */
 		c = (((oreg.h.cl & 0xC0)<<2) | oreg.h.ch) + 1;
 		printf("Disk geometry (C:H:S) = %d:%d:%d (", c, h, s);
@@ -940,6 +1047,8 @@ static char *dt[] = {	"5.25\", 40 track, 360K",
 		sizeit(sect);
 		printf("\n%s disks on system = %d\n",
 			dev&0x80 ? "Fixed" : "Floppy", oreg.h.dl);
+                if (s > 63)  printf("BIOS BUG!!!  sectors returned as zero; 64 assumed\n");
+                if (h > 255) printf("BIOS BUG!!!  heads > 255; BIOS is not IBM compatible\n");
 		if (dev & 0x80) {
 		    if (dev == 0x80) num_hd = oreg.h.dl;
 		    do_edd(dev);
@@ -983,6 +1092,7 @@ void do_get_pt(int dev)
     if (m) print_io_status(m);
     else printf("  okay");
     printf("\n");
+    check_fs();
 }
 
 static
@@ -1074,6 +1184,12 @@ void main(void)
 {
     int m, i, dev;
     
+    set_fs(FS_REG);
+#if DEBUG>=1
+    printf("FS=%04x\n", get_fs());
+    pause();
+#endif
+    
     if (!is_msdos()) {
 /**	atexit(pause);	**/
 	video_fix();	/* for Dumb DELL computers */
@@ -1087,9 +1203,12 @@ void main(void)
         
     segread(&sreg);
     printf("\nBeginning of '_main'\n");
+    check_fs();
     print_sregs(&sreg);
 #endif
+    check_fs();
     banner(DISK_VERSION);
+    check_fs();
     v86test();
     testDX();
 #if DEBUG>=2
@@ -1129,6 +1248,8 @@ void main(void)
     
     if (!is_msdos()) {
 	printf("\n\nInitial SEQ reg 1:  0x%02x\n", video_1);
-	pause();
     }
+    printf("The FS register was %smodified during the tests.\n",
+	    fs_mod ? "" : "NOT ");
+    pause();
 }
