@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2006 John Coffman
- * Copyright 2009-2011 Joachim Wiedorn
+ * Copyright 2009-2013 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -146,11 +146,16 @@
 #define MAJOR_SD16	135 /* SCSI disks    -255 */
 #define MAJOR_DAC960_8	136 /* Ninth Mylex DAC960 PCI RAID controller */
 #define MAJOR_EMD	153 /* Enhanced multi-disk RAID sets */
-#define MAJOR_SATA	160 /* Carmel SATA Disk on first 8-port controller */
-#define MAJOR_SATA2	161 /* Carmel SATA Disk on 2nd 8-port controller */
+#define MAJOR_CARM1	160 /* Carmel SATA Disk on first 8-port controller */
+#define MAJOR_CARM2	161 /* Carmel SATA Disk on 2nd 8-port controller */
+
 /* don't use the following */
 #define MAJOR_MDP	254 /* Enhanced multi-disk RAID sets [experimental?] */
 
+/* high partitions (>15) on SATA hard disks */
+#define MAJOR_SATA1	259 /* high SATA disk partitions */
+#define MAJOR_SATA2	260 /* high SATA disk partitions */
+
 #define MAX_TOKEN	1023 /* max device Token length */
 #define MAX_IMAGE_NAME	15 /* maximum name length (w/o terminating NUL) */
 #define MAX_DESCR_SECTORS  12  /* upper limit on MAX_DESCR_SECS */
@@ -225,7 +230,7 @@
 #define PART_WIN_EXTD_LBA 0xF	/* Win95/98 Extended partition */
 #define PART_LINUX_EXTD   0x85	/* Linux Extended partition */
 #define PART_LINUX_LVM    0x8E /* Linux LVM partition */
-#define PART_OS2_BOOTMGR  0xA	/* OS/2 Boot Manager */
+/* #define PART_OS2_BOOTMGR  0xA	-  OS/2 Boot Manager */
 
 #define PART_DOS12	  1	/* DOS 12 bit FAT partition type */
 #define PART_DOS16_SMALL  4	/* DOS 16 bit FAT partition type, < 32 MB */
